Summary: CERN CA certificates for use with system libraries
Name: CERN-CA-certs
Version: 20120322
Release: 10%{?dist}
URL: http://cern.ch/ca
Packager: Linux.Support@cern.ch
Source0: %{name}-%{version}.tar.gz
License: distributable
Group: System/Security
BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: openssl
Obsoletes: openssl-CERN-CA-certificates openssl-CERN-CA-certificates-slc5 openssl-CERN-CA-certs
BuildArch: noarch


%description
Certificates of CERN Certificate authority (https://cern.ch/ca)
shipped as .crt .bundle and .pem

Also includes VeriSign Class 3 Secure Server CA - G3 which is missing
in system ca-bundle on SLC5/6.

Install this if you would like openssl (and other commands that use
openssl libraries) to trust certificates signed by this CA.


%prep
%setup -q

%build

for i in CERN_Root_CA.crt CERN_Trusted_Certification_Authority.crt VeriSignClass3SecureServerCA-G3.crt; do

  j=`basename $i .crt`
  openssl x509 -inform DER -in "${i}" -outform PEM -out "${j}.pem"

  num=`cat "${j}.pem" | grep -E 'BEGIN.* CERTIFICATE' | wc -l`
  if [ "$num" -gt 1 ]; then
     echo "Error: more than 1 certificate in $j.pem, can't handle"
     exit 7
  fi

  hash=`openssl x509 -in  $j.pem -noout -hash`
%if 0%{?rhel} >= 6
  oldhash=`openssl x509 -in  $j.pem -noout -subject_hash_old`
%endif
  # is this always .0? or should we have the version here?
  # not until we get a clash, this is a uniqifier.
  ln -s "${j}.pem" "${hash}.0"
%if 0%{?rhel} >= 6
  ln -s "${j}.pem" "${oldhash}.0"
%endif
  # subject:
  subject=`openssl x509 -subject -noout -in $j.pem | sed -e 's/subject= *//'`

if [[ "$i" =~ "CERN" ]]; then
  # signing policy
  cat > "${j}.signing_policy" <<EOF
access_id_CA      X509         '$subject'
pos_rights        globus        CA:sign
cond_subjects     globus     '"/DC=ch/DC=cern/*"'
EOF

  ln -s "${j}.signing_policy" "${hash}.signing_policy"
%if 0%{?rhel} >= 6
  ln -s "${j}.signing_policy" "${oldhash}.signing_policy"
%endif

fi

  chmod 0444 *
done

cat VeriSignClass3SecureServerCA-G3.crt CERN_Root_CA.crt CERN_Trusted_Certification_Authority.crt > CERN-bundle.crt
cat VeriSignClass3SecureServerCA-G3.pem CERN_Root_CA.pem CERN_Trusted_Certification_Authority.pem > CERN-bundle.pem


# CRL?

%install

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/pki/tls/{certs,crl}
mkdir -p $RPM_BUILD_ROOT/etc/openldap/cacerts

install -m 0444 CERN* $RPM_BUILD_ROOT/etc/pki/tls/certs/
install -m 0444 *signing_policy $RPM_BUILD_ROOT/etc/pki/tls/certs/ 
install -m 0444 *0 $RPM_BUILD_ROOT/etc/pki/tls/certs/ 
install -m 0444 VeriSign* $RPM_BUILD_ROOT/etc/pki/tls/certs/

# only *.pem certs in openldap cacerts: no signing policy .. etc
install -m 0444 *.pem $RPM_BUILD_ROOT/etc/openldap/cacerts/

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/etc/pki/tls/certs/*
/etc/openldap/cacerts/*

%changelog
* Thu Apr  4 2013 Jaroslaw Polok <jaroslaw.polok@cern.ch> 20120322-10
- only *.pem certificates in /etc/openldap/cacerts/ to avoid 
  authconfig errors.
* Tue Nov 27 2012 Jaroslaw Polok <jaroslaw.polok@cern.ch> 20120322-8
- added VeriSign Class 3 Secure Server CA - G3.

* Tue Jul 24 2012 Jaroslaw Polok <jaroslaw.polok@cern.ch> 20120322-7
- added 'old style hashes' (pre opensssl 1.0)

* Fri Jun 22 2012 Jaroslaw Polok <jaroslaw.polok@cern.ch> 20120622-1
- Added certificcates for openldap
* Fri Jun 22 2012 Thomas Oulevey <thomas.oulevey@cern.ch>
- Fixes for .0 files than were not included in previous package.
 
* Thu Mar 22 2012 Jaroslaw Polok <jaroslaw.polok@cern.ch>
* Tue Feb 16 2010 Jan van Eldik <Jan.van.Eldik@cern.ch>
- Unify builds on SLC4 and SLC5

* Fri May  4 2007 Jan Iven  <jan.iven@cern.ch> -20061003.1
- Initial build.


